@@ -1,4 +1,4 @@
-Shindo.tests("Formatador") do
+Shindo.tests("Formatador: basics") do
 
   tests("#display_line(Formatador)").returns("    Formatador\n") do
     capture_stdout do
@@ -10,6 +10,7 @@ output = <<-OUTPUT
     one
     two
 OUTPUT
+output = Formatador.parse(output)
 
   tests("#display_lines(['one', 'two']").returns(output) do
     capture_stdout do
